pub type NativeLinkAction = LinkAction<OsFileSystem>;Expand description
A native create action that works on the real filesystem.
Aliased Type
pub struct NativeLinkAction { /* private fields */ }pub type NativeLinkAction = LinkAction<OsFileSystem>;A native create action that works on the real filesystem.
pub struct NativeLinkAction { /* private fields */ }